(define-module (gnu packages glicid)
  #:use-module (guix packages)
  #:use-module (guix download)
  #:use-module (guix git-download)
  #:use-module (guix build-system gnu)
  #:use-module (guix licenses)
  #:use-module (gnu packages gawk)
  #:use-module (gnu packages gcc)
  #:use-module (gnu packages commencement)
  #:use-module (guix build-system python)
  #:use-module ((guix licenses) #:prefix license:)
  #:use-module ((guix utils) #:select (target-64bit?))
  #:use-module (gnu packages)
  #:use-module (gnu packages admin)
  #:use-module (gnu packages autotools)
  #:use-module (gnu packages base)
  #:use-module (gnu packages freeipmi)
  #:use-module (gnu packages linux)
  #:use-module (gnu packages mpi)
  #:use-module (gnu packages perl)
  #:use-module (gnu packages pkg-config)
  #:use-module (gnu packages parallel)
  #:use-module (gnu packages storage)
  #:use-module (gnu packages networking)
  #:use-module (gnu packages gtk)  
  #:use-module (gnu packages python)
  #:use-module (gnu packages python-science)
  #:use-module (gnu packages python-xyz)
  #:use-module (gnu packages readline)
  #:use-module (gnu packages tcl)
  #:use-module (gnu packages tls)
  #:use-module (gnu packages commencement)
  #:use-module (gnu packages gcc)
  #:use-module (gnu packages chemistry)
  #:use-module (srfi srfi-1)
  #:use-module (gnu packages mpi)
  #:use-module (gnu packages sssd)
  #:use-module (gnu packages web))



(define-public glicid-hello
  (package
    (name "glicid-hello")
    (version "0.01")
    (source (origin
              (method url-fetch)
              (uri (string-append "mirror://gnu/hello/hello-" version
                     ".tar.gz"))
              (sha256
                (base32
                  "0ssi1wpaf7plaswqqjwigppsg5fyh99vdlb9kzl7c9lng89ndq1i"))))
    (build-system gnu-build-system)
    (arguments '(#:configure-flags '("--enable-silent-rules")))
    (inputs `(("gawk" ,gawk)))
    (synopsis "Hello, GNU world: An example GNU package, modified for GLICID")
    (description "Guess what GNU Hello prints!")
    (home-page "https://www.gnu.org/software/hello/")
    (license gpl3+)))

(define-public glicid-syslog-ng
  (package
    (name "glicid-syslog-ng")
    (version "3.25.1")

    (source (origin
              ;; do not use auto-generated tarballs
              (method git-fetch)
              (uri (git-reference
                     (url "https://github.com/syslog-ng/syslog-ng.git")
                     (commit version)))
              (file-name (git-file-name name version))
              (sha256
                (base32
                  "13br735ig7lygvzyfd15fc2rdygrqm503j6xj5xkrl1r7w2wipq6"))))

    (build-system gnu-build-system)
    (arguments '(#:configure-flags '("--enable-silent-rules")))
    (inputs `(("gawk" ,gawk)))
    (synopsis "Hello, GNU world: An example GNU package, modified for GLICID")
    (description "Guess what GNU Hello prints!")
    (home-page "https://www.gnu.org/software/hello/")
    (license gpl3+)))

(define-public glicid-custom-slurm-19.05
 (package 
  (inherit slurm) 
  (name "glicid-custom-slurm-19.05")
  (version "19.05.6")
  (source 
   (origin
    (method url-fetch)
    (uri (string-append "https://download.schedmd.com/slurm/slurm-" version ".tar.bz2"))
    (sha256 (base32 "1kj79r8hng5gp98ickgvj3im4gr19nzd3p3p8g6rl75axb8jin7h"))
   ))
   (inputs `(("gtk+-2" ,gtk+-2)
	     ("sssd", sssd)
		,@(package-inputs slurm)
  ))  
))

;; (define-public glicid-custom-slurm glicid-custom-slurm-19.05)

(define-public glicid-custom-slurm-20.02
 (package 
  (inherit glicid-custom-slurm-19.05)
  (name "glicid-custom-slurm-20.02")
  (version "20.02.2")
  (source 
   (origin
    (method url-fetch)
    (uri (string-append "https://download.schedmd.com/slurm/slurm-" version ".tar.bz2"))
    (sha256 (base32 "0bna1kyqphw6v7ca3gyfb3nlcpclc9vx8py55w7l7sv8xxsqrrvy"))
   ))
))



(define-public glicid-ceph-14
 (package 
  (inherit ceph) 
  (name "glicid-ceph-14")
  (version "14.2.9")
  (source 
   (origin
    (method url-fetch)
    (uri (string-append "http://download.ceph.com/tarballs/ceph_" version ".orig.tar.gz"))
    (sha256 (base32 "0zkh1a23v8g1fa5flqa2d53lv08ancab3li57gybpqpnja90k7il"))
   ))
))

(define-public glicid-librdkafka-09
 (package 
  (inherit librdkafka) 
  (name "glicid-librdkafka-09")
  (version "0.9.2")
  (source 
   (origin
    (method url-fetch)
    (uri (string-append "https://github.com/edenhill/librdkafka/archive/v" version ".tar.gz"))
    (sha256 (base32 "0938yn1msaq8xcj5z7b3jcdy6rslh9kxmvz01r8rdcgbarlvchy2"))
   ))
))


(define-public glicid-ceph-15
 (package 
  (inherit ceph) 
  (name "glicid-ceph-15")
  (version "15.2.1")
  (source 
   (origin
    (method url-fetch)
    (uri (string-append "http://download.ceph.com/tarballs/ceph_" version ".orig.tar.gz"))
    (sha256 (base32 "0ql288dcpddi4kp3f6bcvipgi0hc8rqbsr38a18a4ia5nasfvib8"))
   ))
   (inputs `(("glicid-librdkafka-09" ,glicid-librdkafka-09)
                ,@(package-inputs ceph)
  ))  

))


(define-public glicid-x2go
 (package 
  (name "glicid-x2go")
  (version "4.1.0.3")
  (source 
   (origin
    (method url-fetch)
    (uri (string-append "https://code.x2go.org/releases/source/x2goserver/x2goserver-" version ".tar.gz"))
    (sha256 (base32 "1l6wd708kbipib4ldprfiihqmj4895nifg0bkws4x97majislxk7"))
   ))

    (native-inputs
     `(("autoconf" ,autoconf)
       ("automake" ,automake)
       ("libtool" ,libtool)))

   (inputs
    `(("perl" , perl)))

   (build-system gnu-build-system)
   (synopsis "X2go")
   (description "X2go")
   (license "not checked")
   (home-page "https://wiki.x2go.org")
  )  
)

;; pour futures customisations.

(define-public glicid-openmpi-gcc-8
 (package
  (inherit openmpi)
  (name "glicid-openpmi-gcc-8")
  (inputs `(("gcc-8", gcc-8)
            ("gfortran-8", gfortran-8)
                  ,@(package-inputs openmpi)))
  )
)

(define-public glicid-openmpi-gcc-9
 (package
  (inherit openmpi)
  (name "glicid-openpmi-gcc-9")
  (inputs `(("gcc-9", gcc-9)
            ("gfortran-9", gfortran-9)
                  ,@(package-inputs openmpi)))
  )
)

(define-public glicid-openmpi-gcc-10
 (package
  (inherit openmpi)
  (name "glicid-openpmi-gcc-10")
  (inputs `(("gcc-10", gcc-10)
            ("gfortran-10", gfortran-10)
                  ,@(package-inputs openmpi)))
  )
)

(define-public glicid-gromacs-gcc-10
 (package
  (inherit gromacs)
  (name "glicid-gromacs-gcc-10")
  (inputs `(("gcc-10", gcc-10)
            ("gfortran-10", gfortran-10)
            ("glicid-openmpi-gcc-10")
                    ,@(package-inputs gromacs)))
))


;;; glicid.scm ends here
